@@ -5,6 +5,8 @@ use utf8;
 use Moose;
 use 5.0100;
 
+our $VERSION = $App::iTan::VERSION;
+
 extends qw(MooseX::App::Cmd::Command);
 with qw(App::iTan::Utils);
 
@@ -17,8 +19,8 @@ has 'index' => (
 
 use Text::Table;
 
-sub run {
-    my ($self) = @_;
+sub execute {
+    my ( $self, $opts, $args ) = @_;
 
     my $sth
         = $self->dbh->prepare(
@@ -39,7 +41,6 @@ sub run {
             $tan_data->{valid},
             $self->_decrypt_string( $tan_data->{itan} ),
             $tan_data->{imported},
-            $tan_data->{imported},
             $tan_data->{used},
             $tan_data->{memo} );
     }
@@ -51,11 +52,16 @@ sub run {
     return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 =head1 NAME 
 
 App::iTan::Command::info - Fetch info for a tan index number
+
 =head1 DESCRIPTION
 
+See L<App::iTan> for detailed documentation
+
 =cut
 
 1;
